Frequency of given names (first only) in the database

Name              Occurrences

Henry                  4
Alexandra              3
Edward                 3
George                 3
A2                     2
A3B3                   2
Alexander              2
David                  2
Elizabeth              2
James                  2
Margaret               2
Marina                 2
Mark                   2
Sarah                  2
William                2
A3                     1
A4B4C4D4               1
Alice                  1
Andrew                 1
Angela                 1
Angus                  1
Anne                   1
Anthony                1
B1                     1
B2                     1
Beatrice               1
Benjamin               1
Bessiewallis           1
Birgitte               1
Charles                1
Davina                 1
Diana                  1
Edward_VII             1
Edward_VIII            1
Elizabeth_II           1
Ellen                  1
Emily                  1
Eugenie                1
Frederick              1
Fredericka             1
Gabriella              1
George_V               1
George_VI              1
Gerald                 1
Helen                  1
Jeremy                 1
John                   1
Julia                  1
Julie                  1
Katharine              1
Marie-Christine        1
Marion                 1
Martin                 1
Mary                   1
Mary_of_Teck           1
Michael                1
Nicholas               1
Patricia               1
Paul                   1
Peter                  1
Philip                 1
Richard                1
Rose                   1
Rowan                  1
Sophie                 1
Sylvana                1
Thomas                 1
Zara                   1
a3b3                   1
a4b4c4d4               1
