Previous
birth       Next
record      birth
MF         M      F
00        21     16  (excluded from statistics)

01         2      2
10         5      9
11         4      1
20         1      1
21         3      0
31         1      0
41         1      0
Total:    17     13
7 birth combinations found
30 'next' individuals (excluding firstborns)

Male excess of previous births= 47% +/- 69%
Male excess of next births    = 13% +/- 49%
Correlation between previous and next = -36%

Fraction of births that match (in sex) a run of previous births in the
same family.  Children of unknown sex ignored in this tabulation.

Run    Total   Matching
Length Cases     Cases     %
1         30        14    46
2          4         3    75
