# Copyright 1998-2005, Paul Johnson (pjcj@cpan.org)

# This software is free.  It is licensed under the same terms as Perl itself.

# The latest version of this software should be available from my homepage:
# http://www.pjcj.net

# This file was automatically generated from gedcom-5.5.grammar
# by Paul Johnson
# on Tue May  3 21:47:48 2005

# Do not edit this file.
# Edit gedcom-5.5.grammar if changes need to be made.
# Edit parse_grammar or Makefile.PL to increase the legibility of this file.
# (Removal of the leading spaces nearly halves the size of the file.)

# Version 1.15 - 3rd May 2005

use strict;

require 5.005;

package Gedcom::Grammar_5_5;

use vars qw($VERSION $grammar);
$VERSION = 1.15;

$grammar = bless( {
fh => \*Symbol::GEN0,
file => 'gedcom-5.5.grammar',
gedcom => {},
items => [
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => 0,
line => 3,
max => 1,
min => 1,
pointer => '',
value => '<<HEADER>>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => 0,
line => 4,
max => 1,
min => 0,
pointer => '',
value => '<<SUBMISSION_RECORD>>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => 0,
line => 5,
max => 'M',
min => 0,
pointer => '',
value => '<<RECORD>>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => 0,
line => 6,
max => 1,
min => 1,
tag => 'TRLR'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 1,
structure => 'GEDCOM'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 12,
max => 1,
min => 0,
pointer => '',
tag => 'VERS',
value => '<VERSION_NUMBER>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 13,
max => 1,
min => 0,
pointer => '',
tag => 'NAME',
value => '<NAME_OF_PRODUCT>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+3',
line => 15,
max => 1,
min => 0,
pointer => '',
value => '<<ADDRESS_STRUCTURE>>'
}, 'Gedcom::Grammar' )
],
level => '+2',
line => 14,
max => 1,
min => 0,
pointer => '',
tag => 'CORP',
value => '<NAME_OF_BUSINESS>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+3',
line => 17,
max => 1,
min => 0,
pointer => '',
tag => 'DATE',
value => '<PUBLICATION_DATE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+3',
line => 18,
max => 1,
min => 0,
pointer => '',
tag => 'COPR',
value => '<COPYRIGHT_SOURCE_DATA>'
}, 'Gedcom::Grammar' )
],
level => '+2',
line => 16,
max => 1,
min => 0,
pointer => '',
tag => 'DATA',
value => '<NAME_OF_SOURCE_DATA>'
}, 'Gedcom::Grammar' )
],
level => '+1',
line => 11,
max => 1,
min => 1,
pointer => '',
tag => 'SOUR',
value => '<APPROVED_SYSTEM_ID>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 19,
max => 1,
min => 0,
pointer => '',
tag => 'DEST',
value => '<RECEIVING_SYSTEM_NAME>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 21,
max => 1,
min => 0,
pointer => '',
tag => 'TIME',
value => '<TIME_VALUE>'
}, 'Gedcom::Grammar' )
],
level => '+1',
line => 20,
max => 1,
min => 0,
pointer => '',
tag => 'DATE',
value => '<TRANSMISSION_DATE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 22,
max => 1,
min => 1,
pointer => 1,
tag => 'SUBM',
value => '<XREF:SUBM>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 23,
max => 1,
min => 0,
pointer => 1,
tag => 'SUBN',
value => '<XREF:SUBN>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 24,
max => 1,
min => 0,
pointer => '',
tag => 'FILE',
value => '<FILE_NAME>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 25,
max => 1,
min => 0,
pointer => '',
tag => 'COPR',
value => '<COPYRIGHT_GEDCOM_FILE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 27,
max => 1,
min => 1,
pointer => '',
tag => 'VERS',
value => '<VERSION_NUMBER>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 28,
max => 1,
min => 1,
pointer => '',
tag => 'FORM',
value => '<GEDCOM_FORM>'
}, 'Gedcom::Grammar' )
],
level => '+1',
line => 26,
max => 1,
min => 1,
tag => 'GEDC'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 30,
max => 1,
min => 0,
pointer => '',
tag => 'VERS',
value => '<VERSION_NUMBER>'
}, 'Gedcom::Grammar' )
],
level => '+1',
line => 29,
max => 1,
min => 1,
pointer => '',
tag => 'CHAR',
value => '<CHARACTER_SET>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 31,
max => 1,
min => 0,
pointer => '',
tag => 'LANG',
value => '<LANGUAGE_OF_TEXT>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 33,
max => 1,
min => 1,
pointer => '',
tag => 'FORM',
value => '<PLACE_HIERARCHY>'
}, 'Gedcom::Grammar' )
],
level => '+1',
line => 32,
max => 1,
min => 0,
tag => 'PLAC'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 35,
max => 'M',
min => 0,
pointer => '',
tag => 'CONT',
value => '<GEDCOM_CONTENT_DESCRIPTION>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => '+2',
line => 36,
max => 'M',
min => 0,
pointer => '',
tag => 'CONC',
value => '<GEDCOM_CONTENT_DESCRIPTION>'
}, 'Gedcom::Grammar' )
],
level => '+1',
line => 34,
max => 1,
min => 0,
pointer => '',
tag => 'NOTE',
value => '<GEDCOM_CONTENT_DESCRIPTION>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 10,
max => 1,
min => 1,
tag => 'HEAD'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 8,
structure => 'HEADER'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => 0,
line => 41,
max => 1,
min => 1,
pointer => '',
selection => 1,
value => '<<FAM_RECORD>>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => 0,
line => 43,
max => 1,
min => 1,
pointer => '',
selection => 1,
value => '<<INDIVIDUAL_RECORD>>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => 0,
line => 45,
max => 'M',
min => 1,
pointer => '',
selection => 1,
value => '<<MULTIMEDIA_RECORD>>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => 0,
line => 47,
max => 1,
min => 1,
pointer => '',
selection => 1,
value => '<<NOTE_RECORD>>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => 0,
line => 49,
max => 1,
min => 1,
pointer => '',
selection => 1,
value => '<<REPOSITORY_RECORD>>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => 0,
line => 51,
max => 1,
min => 1,
pointer => '',
selection => 1,
value => '<<SOURCE_RECORD>>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => 0,
line => 53,
max => 1,
min => 1,
pointer => '',
selection => 1,
value => '<<SUBMITTER_RECORD>>'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 39,
selection => 1,
structure => 'RECORD'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+3',
line => 61,
max => 1,
min => 1,
pointer => '',
tag => 'AGE',
value => '<AGE_AT_EVENT>'
}, 'Gedcom::Grammar' )
],
level => '+2',
line => 60,
max => 1,
min => 0,
tag => 'HUSB'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+3',
line => 63,
max => 1,
min => 1,
pointer => '',
tag => 'AGE',
value => '<AGE_AT_EVENT>'
}, 'Gedcom::Grammar' )
],
level => '+2',
line => 62,
max => 1,
min => 0,
tag => 'WIFE'
}, 'Gedcom::Grammar' )
],
level => '+1',
line => 59,
max => 'M',
min => 0,
pointer => '',
value => '<<FAMILY_EVENT_STRUCTURE>>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 64,
max => 1,
min => 0,
pointer => 1,
tag => 'HUSB',
value => '<XREF:INDI>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 65,
max => 1,
min => 0,
pointer => 1,
tag => 'WIFE',
value => '<XREF:INDI>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 66,
max => 'M',
min => 0,
pointer => 1,
tag => 'CHIL',
value => '<XREF:INDI>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 67,
max => 1,
min => 0,
pointer => '',
tag => 'NCHI',
value => '<COUNT_OF_CHILDREN>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 68,
max => 'M',
min => 0,
pointer => 1,
tag => 'SUBM',
value => '<XREF:SUBM>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 69,
max => 'M',
min => 0,
pointer => '',
value => '<<LDS_SPOUSE_SEALING>>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 70,
max => 'M',
min => 0,
pointer => '',
value => '<<SOURCE_CITATION>>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 71,
max => 'M',
min => 0,
pointer => '',
value => '<<MULTIMEDIA_LINK>>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 72,
max => 'M',
min => 0,
pointer => '',
value => '<<NOTE_STRUCTURE>>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 74,
max => 1,
min => 0,
pointer => '',
tag => 'TYPE',
value => '<USER_REFERENCE_TYPE>'
}, 'Gedcom::Grammar' )
],
level => '+1',
line => 73,
max => 'M',
min => 0,
pointer => '',
tag => 'REFN',
value => '<USER_REFERENCE_NUMBER>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 75,
max => 1,
min => 0,
pointer => '',
tag => 'RIN',
value => '<AUTOMATED_RECORD_ID>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => '+1',
line => 76,
max => 1,
min => 0,
pointer => '',
value => '<<CHANGE_DATE>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 58,
max => 1,
min => 1,
tag => 'FAM',
xref => '<XREF:FAM>'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 56,
structure => 'FAM_RECORD'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 82,
max => 1,
min => 0,
pointer => '',
tag => 'RESN',
value => '<RESTRICTION_NOTICE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 83,
max => 'M',
min => 0,
pointer => '',
value => '<<PERSONAL_NAME_STRUCTURE>>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 84,
max => 1,
min => 0,
pointer => '',
tag => 'SEX',
value => '<SEX_VALUE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 85,
max => 'M',
min => 0,
pointer => '',
value => '<<INDIVIDUAL_EVENT_STRUCTURE>>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 86,
max => 'M',
min => 0,
pointer => '',
value => '<<INDIVIDUAL_ATTRIBUTE_STRUCTURE>>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 87,
max => 'M',
min => 0,
pointer => '',
value => '<<LDS_INDIVIDUAL_ORDINANCE>>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 88,
max => 'M',
min => 0,
pointer => '',
value => '<<CHILD_TO_FAMILY_LINK>>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 89,
max => 'M',
min => 0,
pointer => '',
value => '<<SPOUSE_TO_FAMILY_LINK>>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 90,
max => 'M',
min => 0,
pointer => 1,
tag => 'SUBM',
value => '<XREF:SUBM>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 91,
max => 'M',
min => 0,
pointer => '',
value => '<<ASSOCIATION_STRUCTURE>>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 92,
max => 'M',
min => 0,
pointer => 1,
tag => 'ALIA',
value => '<XREF:INDI>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 93,
max => 'M',
min => 0,
pointer => 1,
tag => 'ANCI',
value => '<XREF:SUBM>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 94,
max => 'M',
min => 0,
pointer => 1,
tag => 'DESI',
value => '<XREF:SUBM>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 95,
max => 'M',
min => 0,
pointer => '',
value => '<<SOURCE_CITATION>>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 96,
max => 'M',
min => 0,
pointer => '',
value => '<<MULTIMEDIA_LINK>>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 97,
max => 'M',
min => 0,
pointer => '',
value => '<<NOTE_STRUCTURE>>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 98,
max => 1,
min => 0,
pointer => '',
tag => 'RFN',
value => '<PERMANENT_RECORD_FILE_NUMBER>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 99,
max => 1,
min => 0,
pointer => '',
tag => 'AFN',
value => '<ANCESTRAL_FILE_NUMBER>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 101,
max => 1,
min => 0,
pointer => '',
tag => 'TYPE',
value => '<USER_REFERENCE_TYPE>'
}, 'Gedcom::Grammar' )
],
level => '+1',
line => 100,
max => 'M',
min => 0,
pointer => '',
tag => 'REFN',
value => '<USER_REFERENCE_NUMBER>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 102,
max => 1,
min => 0,
pointer => '',
tag => 'RIN',
value => '<AUTOMATED_RECORD_ID>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => '+1',
line => 103,
max => 1,
min => 0,
pointer => '',
value => '<<CHANGE_DATE>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 81,
max => 1,
min => 1,
tag => 'INDI',
xref => '<XREF:INDI>'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 79,
structure => 'INDIVIDUAL_RECORD'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 109,
max => 1,
min => 1,
pointer => '',
tag => 'FORM',
value => '<MULTIMEDIA_FORMAT>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 110,
max => 1,
min => 0,
pointer => '',
tag => 'TITL',
value => '<DESCRIPTIVE_TITLE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 111,
max => 'M',
min => 0,
pointer => '',
value => '<<NOTE_STRUCTURE>>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 113,
max => 'M',
min => 1,
pointer => '',
tag => 'CONT',
value => '<ENCODED_MULTIMEDIA_LINE>'
}, 'Gedcom::Grammar' )
],
level => '+1',
line => 112,
max => 1,
min => 1,
tag => 'BLOB'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 114,
max => 1,
min => 0,
pointer => 1,
tag => 'OBJE',
value => '<XREF:OBJE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 116,
max => 1,
min => 0,
pointer => '',
tag => 'TYPE',
value => '<USER_REFERENCE_TYPE>'
}, 'Gedcom::Grammar' )
],
level => '+1',
line => 115,
max => 'M',
min => 0,
pointer => '',
tag => 'REFN',
value => '<USER_REFERENCE_NUMBER>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 117,
max => 1,
min => 0,
pointer => '',
tag => 'RIN',
value => '<AUTOMATED_RECORD_ID>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => '+1',
line => 118,
max => 1,
min => 0,
pointer => '',
value => '<<CHANGE_DATE>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 108,
max => 1,
min => 1,
tag => 'OBJE',
xref => '<XREF:OBJE>'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 106,
structure => 'MULTIMEDIA_RECORD'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 124,
max => 'M',
min => 0,
pointer => '',
tag => 'CONC',
value => '<SUBMITTER_TEXT>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 125,
max => 'M',
min => 0,
pointer => '',
tag => 'CONT',
value => '<SUBMITTER_TEXT>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 126,
max => 'M',
min => 0,
pointer => '',
value => '<<SOURCE_CITATION>>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 128,
max => 1,
min => 0,
pointer => '',
tag => 'TYPE',
value => '<USER_REFERENCE_TYPE>'
}, 'Gedcom::Grammar' )
],
level => '+1',
line => 127,
max => 'M',
min => 0,
pointer => '',
tag => 'REFN',
value => '<USER_REFERENCE_NUMBER>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 129,
max => 1,
min => 0,
pointer => '',
tag => 'RIN',
value => '<AUTOMATED_RECORD_ID>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => '+1',
line => 130,
max => 1,
min => 0,
pointer => '',
value => '<<CHANGE_DATE>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 123,
max => 1,
min => 1,
pointer => '',
tag => 'NOTE',
value => '<SUBMITTER_TEXT>',
xref => '<XREF:NOTE>'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 121,
structure => 'NOTE_RECORD'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 136,
max => 1,
min => 0,
pointer => '',
tag => 'NAME',
value => '<NAME_OF_REPOSITORY>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 137,
max => 1,
min => 0,
pointer => '',
value => '<<ADDRESS_STRUCTURE>>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 138,
max => 'M',
min => 0,
pointer => '',
value => '<<NOTE_STRUCTURE>>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 140,
max => 1,
min => 0,
pointer => '',
tag => 'TYPE',
value => '<USER_REFERENCE_TYPE>'
}, 'Gedcom::Grammar' )
],
level => '+1',
line => 139,
max => 'M',
min => 0,
pointer => '',
tag => 'REFN',
value => '<USER_REFERENCE_NUMBER>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 141,
max => 1,
min => 0,
pointer => '',
tag => 'RIN',
value => '<AUTOMATED_RECORD_ID>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => '+1',
line => 142,
max => 1,
min => 0,
pointer => '',
value => '<<CHANGE_DATE>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 135,
max => 1,
min => 1,
tag => 'REPO',
xref => '<XREF:REPO>'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 133,
structure => 'REPOSITORY_RECORD'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+3',
line => 150,
max => 1,
min => 0,
pointer => '',
tag => 'DATE',
value => '<DATE_PERIOD>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+3',
line => 151,
max => 1,
min => 0,
pointer => '',
tag => 'PLAC',
value => '<SOURCE_JURISDICTION_PLACE>'
}, 'Gedcom::Grammar' )
],
level => '+2',
line => 149,
max => 'M',
min => 0,
pointer => '',
tag => 'EVEN',
value => '<EVENTS_RECORDED>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 152,
max => 1,
min => 0,
pointer => '',
tag => 'AGNC',
value => '<RESPONSIBLE_AGENCY>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 153,
max => 'M',
min => 0,
pointer => '',
value => '<<NOTE_STRUCTURE>>'
}, 'Gedcom::Grammar' )
],
level => '+1',
line => 148,
max => 1,
min => 0,
tag => 'DATA'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 155,
max => 'M',
min => 0,
pointer => '',
tag => 'CONT',
value => '<SOURCE_ORIGINATOR>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 156,
max => 'M',
min => 0,
pointer => '',
tag => 'CONC',
value => '<SOURCE_ORIGINATOR>'
}, 'Gedcom::Grammar' )
],
level => '+1',
line => 154,
max => 1,
min => 0,
pointer => '',
tag => 'AUTH',
value => '<SOURCE_ORIGINATOR>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 158,
max => 'M',
min => 0,
pointer => '',
tag => 'CONT',
value => '<SOURCE_DESCRIPTIVE_TITLE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 159,
max => 'M',
min => 0,
pointer => '',
tag => 'CONC',
value => '<SOURCE_DESCRIPTIVE_TITLE>'
}, 'Gedcom::Grammar' )
],
level => '+1',
line => 157,
max => 1,
min => 0,
pointer => '',
tag => 'TITL',
value => '<SOURCE_DESCRIPTIVE_TITLE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 160,
max => 1,
min => 0,
pointer => '',
tag => 'ABBR',
value => '<SOURCE_FILED_BY_ENTRY>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 162,
max => 'M',
min => 0,
pointer => '',
tag => 'CONT',
value => '<SOURCE_PUBLICATION_FACTS>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 163,
max => 'M',
min => 0,
pointer => '',
tag => 'CONC',
value => '<SOURCE_PUBLICATION_FACTS>'
}, 'Gedcom::Grammar' )
],
level => '+1',
line => 161,
max => 1,
min => 0,
pointer => '',
tag => 'PUBL',
value => '<SOURCE_PUBLICATION_FACTS>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 165,
max => 'M',
min => 0,
pointer => '',
tag => 'CONT',
value => '<TEXT_FROM_SOURCE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 166,
max => 'M',
min => 0,
pointer => '',
tag => 'CONC',
value => '<TEXT_FROM_SOURCE>'
}, 'Gedcom::Grammar' )
],
level => '+1',
line => 164,
max => 1,
min => 0,
pointer => '',
tag => 'TEXT',
value => '<TEXT_FROM_SOURCE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 167,
max => 1,
min => 0,
pointer => '',
value => '<<SOURCE_REPOSITORY_CITATION>>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 168,
max => 'M',
min => 0,
pointer => '',
value => '<<MULTIMEDIA_LINK>>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 169,
max => 'M',
min => 0,
pointer => '',
value => '<<NOTE_STRUCTURE>>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 171,
max => 1,
min => 0,
pointer => '',
tag => 'TYPE',
value => '<USER_REFERENCE_TYPE>'
}, 'Gedcom::Grammar' )
],
level => '+1',
line => 170,
max => 'M',
min => 0,
pointer => '',
tag => 'REFN',
value => '<USER_REFERENCE_NUMBER>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 172,
max => 1,
min => 0,
pointer => '',
tag => 'RIN',
value => '<AUTOMATED_RECORD_ID>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => '+1',
line => 173,
max => 1,
min => 0,
pointer => '',
value => '<<CHANGE_DATE>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 147,
max => 1,
min => 1,
tag => 'SOUR',
xref => '<XREF:SOUR>'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 145,
structure => 'SOURCE_RECORD'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 179,
max => 1,
min => 0,
pointer => 1,
tag => 'SUBM',
value => '<XREF:SUBM>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 180,
max => 1,
min => 0,
pointer => '',
tag => 'FAMF',
value => '<NAME_OF_FAMILY_FILE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 181,
max => 1,
min => 0,
pointer => '',
tag => 'TEMP',
value => '<TEMPLE_CODE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 182,
max => 1,
min => 0,
pointer => '',
tag => 'ANCE',
value => '<GENERATIONS_OF_ANCESTORS>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 183,
max => 1,
min => 0,
pointer => '',
tag => 'DESC',
value => '<GENERATIONS_OF_DESCENDANTS>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 184,
max => 1,
min => 0,
pointer => '',
tag => 'ORDI',
value => '<ORDINANCE_PROCESS_FLAG>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => '+1',
line => 185,
max => 1,
min => 0,
pointer => '',
tag => 'RIN',
value => '<AUTOMATED_RECORD_ID>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 178,
max => 1,
min => 1,
tag => 'SUBN',
xref => '<XREF:SUBN>'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 176,
structure => 'SUBMISSION_RECORD'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 191,
max => 1,
min => 1,
pointer => '',
tag => 'NAME',
value => '<SUBMITTER_NAME>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 192,
max => 1,
min => 0,
pointer => '',
value => '<<ADDRESS_STRUCTURE>>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 193,
max => 'M',
min => 0,
pointer => '',
value => '<<MULTIMEDIA_LINK>>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 194,
max => 3,
min => 0,
pointer => '',
tag => 'LANG',
value => '<LANGUAGE_PREFERENCE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 195,
max => 1,
min => 0,
pointer => '',
tag => 'RFN',
value => '<SUBMITTER_REGISTERED_RFN>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 196,
max => 1,
min => 0,
pointer => '',
tag => 'RIN',
value => '<AUTOMATED_RECORD_ID>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => '+1',
line => 197,
max => 1,
min => 0,
pointer => '',
value => '<<CHANGE_DATE>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 190,
max => 1,
min => 1,
tag => 'SUBM',
xref => '<XREF:SUBM>'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 188,
structure => 'SUBMITTER_RECORD'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 203,
max => 'M',
min => 0,
pointer => '',
tag => 'CONT',
value => '<ADDRESS_LINE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 204,
max => 1,
min => 0,
pointer => '',
tag => 'ADR1',
value => '<ADDRESS_LINE1>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 205,
max => 1,
min => 0,
pointer => '',
tag => 'ADR2',
value => '<ADDRESS_LINE2>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 206,
max => 1,
min => 0,
pointer => '',
tag => 'CITY',
value => '<ADDRESS_CITY>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 207,
max => 1,
min => 0,
pointer => '',
tag => 'STAE',
value => '<ADDRESS_STATE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 208,
max => 1,
min => 0,
pointer => '',
tag => 'POST',
value => '<ADDRESS_POSTAL_CODE>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => '+1',
line => 209,
max => 1,
min => 0,
pointer => '',
tag => 'CTRY',
value => '<ADDRESS_COUNTRY>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 202,
max => 1,
min => 0,
pointer => '',
tag => 'ADDR',
value => '<ADDRESS_LINE>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => 0,
line => 210,
max => 3,
min => 0,
pointer => '',
tag => 'PHON',
value => '<PHONE_NUMBER>'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 200,
structure => 'ADDRESS_STRUCTURE'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 216,
max => 1,
min => 1,
pointer => '',
tag => 'TYPE',
value => '<RECORD_TYPE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 217,
max => 1,
min => 1,
pointer => '',
tag => 'RELA',
value => '<RELATION_IS_DESCRIPTOR>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 218,
max => 'M',
min => 0,
pointer => '',
value => '<<NOTE_STRUCTURE>>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => '+1',
line => 219,
max => 'M',
min => 0,
pointer => '',
value => '<<SOURCE_CITATION>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 215,
max => 'M',
min => 0,
pointer => 1,
tag => 'ASSO',
value => '<XREF:INDI>'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 213,
structure => 'ASSOCIATION_STRUCTURE'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 226,
max => 1,
min => 0,
pointer => '',
tag => 'TIME',
value => '<TIME_VALUE>'
}, 'Gedcom::Grammar' )
],
level => '+1',
line => 225,
max => 1,
min => 1,
pointer => '',
tag => 'DATE',
value => '<CHANGE_DATE>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => '+1',
line => 227,
max => 'M',
min => 0,
pointer => '',
value => '<<NOTE_STRUCTURE>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 224,
max => 1,
min => 1,
tag => 'CHAN'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 222,
structure => 'CHANGE_DATE'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 233,
max => 'M',
min => 0,
pointer => '',
tag => 'PEDI',
value => '<PEDIGREE_LINKAGE_TYPE>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => '+1',
line => 234,
max => 'M',
min => 0,
pointer => '',
value => '<<NOTE_STRUCTURE>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 232,
max => 1,
min => 1,
pointer => 1,
tag => 'FAMC',
value => '<XREF:FAM>'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 230,
structure => 'CHILD_TO_FAMILY_LINK'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => 0,
line => 239,
max => 1,
min => 0,
pointer => '',
tag => 'TYPE',
value => '<EVENT_DESCRIPTOR>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => 0,
line => 240,
max => 1,
min => 0,
pointer => '',
tag => 'DATE',
value => '<DATE_VALUE>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => 0,
line => 241,
max => 1,
min => 0,
pointer => '',
value => '<<PLACE_STRUCTURE>>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => 0,
line => 242,
max => 1,
min => 0,
pointer => '',
value => '<<ADDRESS_STRUCTURE>>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => 0,
line => 243,
max => 1,
min => 0,
pointer => '',
tag => 'AGE',
value => '<AGE_AT_EVENT>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => 0,
line => 244,
max => 1,
min => 0,
pointer => '',
tag => 'AGNC',
value => '<RESPONSIBLE_AGENCY>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => 0,
line => 245,
max => 1,
min => 0,
pointer => '',
tag => 'CAUS',
value => '<CAUSE_OF_EVENT>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => 0,
line => 246,
max => 'M',
min => 0,
pointer => '',
value => '<<SOURCE_CITATION>>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => 0,
line => 247,
max => 'M',
min => 0,
pointer => '',
value => '<<MULTIMEDIA_LINK>>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => 0,
line => 248,
max => 'M',
min => 0,
pointer => '',
value => '<<NOTE_STRUCTURE>>'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 237,
structure => 'EVENT_DETAIL'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 256,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 255,
max => 1,
min => 1,
tag => 'ANUL'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 259,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 258,
max => 1,
min => 1,
tag => 'CENS'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 262,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 261,
max => 1,
min => 1,
tag => 'DIV'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 265,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 264,
max => 1,
min => 1,
tag => 'DIVF'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 268,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 267,
max => 1,
min => 1,
tag => 'ENGA'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 271,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 270,
max => 1,
min => 1,
tag => 'MARR'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 274,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 273,
max => 1,
min => 1,
tag => 'MARB'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 277,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 276,
max => 1,
min => 1,
tag => 'MARC'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 280,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 279,
max => 1,
min => 1,
tag => 'MARL'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 283,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 282,
max => 1,
min => 1,
tag => 'MARS'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 286,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 285,
max => 1,
min => 1,
tag => 'EVEN'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 252,
selection => 1,
structure => 'FAMILY_EVENT_STRUCTURE'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 295,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 294,
max => 1,
min => 1,
pointer => '',
tag => 'CAST',
value => '<CASTE_NAME>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 298,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 297,
max => 1,
min => 1,
pointer => '',
tag => 'DSCR',
value => '<PHYSICAL_DESCRIPTION>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 301,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 300,
max => 1,
min => 1,
pointer => '',
tag => 'EDUC',
value => '<SCHOLASTIC_ACHIEVEMENT>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 304,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 303,
max => 1,
min => 1,
pointer => '',
tag => 'IDNO',
value => '<NATIONAL_ID_NUMBER>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 307,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 306,
max => 1,
min => 1,
pointer => '',
tag => 'NATI',
value => '<NATIONAL_OR_TRIBAL_ORIGIN>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 310,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 309,
max => 1,
min => 1,
pointer => '',
tag => 'NCHI',
value => '<COUNT_OF_CHILDREN>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 313,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 312,
max => 1,
min => 1,
pointer => '',
tag => 'NMR',
value => '<COUNT_OF_MARRIAGES>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 316,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 315,
max => 1,
min => 1,
pointer => '',
tag => 'OCCU',
value => '<OCCUPATION>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 319,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 318,
max => 1,
min => 1,
pointer => '',
tag => 'PROP',
value => '<POSSESSIONS>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 322,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 321,
max => 1,
min => 1,
pointer => '',
tag => 'RELI',
value => '<RELIGIOUS_AFFILIATION>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 325,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 324,
max => 1,
min => 1,
tag => 'RESI'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 328,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 327,
max => 1,
min => 0,
pointer => '',
tag => 'SSN',
value => '<SOCIAL_SECURITY_NUMBER>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 331,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 330,
max => 1,
min => 1,
pointer => '',
tag => 'TITL',
value => '<NOBILITY_TYPE_TITLE>'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 291,
selection => 1,
structure => 'INDIVIDUAL_ATTRIBUTE_STRUCTURE'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 339,
max => 1,
min => 0,
pointer => '',
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => '+1',
line => 340,
max => 1,
min => 0,
pointer => 1,
selection => 1,
tag => 'FAMC',
value => '<XREF:FAM>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 338,
max => 1,
min => 1,
tag => 'BIRT'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 343,
max => 1,
min => 0,
pointer => '',
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => '+1',
line => 344,
max => 1,
min => 0,
pointer => 1,
selection => 1,
tag => 'FAMC',
value => '<XREF:FAM>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 342,
max => 1,
min => 1,
tag => 'CHR'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 347,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 346,
max => 1,
min => 1,
tag => 'DEAT'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 350,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 349,
max => 1,
min => 1,
tag => 'BURI'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 353,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 352,
max => 1,
min => 1,
tag => 'CREM'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 356,
max => 1,
min => 0,
pointer => '',
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+2',
line => 358,
max => 1,
min => 0,
pointer => '',
selection => 1,
tag => 'ADOP',
value => '<ADOPTED_BY_WHICH_PARENT>'
}, 'Gedcom::Grammar' )
],
level => '+1',
line => 357,
max => 1,
min => 0,
pointer => 1,
tag => 'FAMC',
value => '<XREF:FAM>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 355,
max => 1,
min => 1,
tag => 'ADOP'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 361,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 360,
max => 1,
min => 1,
tag => 'BAPM'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 364,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 363,
max => 1,
min => 1,
tag => 'BARM'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 367,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 366,
max => 1,
min => 1,
tag => 'BASM'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 370,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 369,
max => 1,
min => 1,
tag => 'BLES'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 373,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 372,
max => 1,
min => 1,
tag => 'CHRA'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 376,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 375,
max => 1,
min => 1,
tag => 'CONF'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 379,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 378,
max => 1,
min => 1,
tag => 'FCOM'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 382,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 381,
max => 1,
min => 1,
tag => 'ORDN'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 385,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 384,
max => 1,
min => 1,
tag => 'NATU'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 388,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 387,
max => 1,
min => 1,
tag => 'EMIG'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 391,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 390,
max => 1,
min => 1,
tag => 'IMMI'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 394,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 393,
max => 1,
min => 1,
tag => 'CENS'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 397,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 396,
max => 1,
min => 1,
tag => 'PROB'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 400,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 399,
max => 1,
min => 1,
tag => 'WILL'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 403,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 402,
max => 1,
min => 1,
tag => 'GRAD'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 406,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 405,
max => 1,
min => 1,
tag => 'RETI'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 409,
max => 1,
min => 0,
pointer => '',
selection => 1,
value => '<<EVENT_DETAIL>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 408,
max => 1,
min => 1,
tag => 'EVEN'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 335,
selection => 1,
structure => 'INDIVIDUAL_EVENT_STRUCTURE'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 417,
max => 1,
min => 0,
pointer => '',
tag => 'STAT',
value => '<LDS_BAPTISM_DATE_STATUS>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 418,
max => 1,
min => 0,
pointer => '',
tag => 'DATE',
value => '<DATE_LDS_ORD>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 419,
max => 1,
min => 0,
pointer => '',
tag => 'TEMP',
value => '<TEMPLE_CODE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 420,
max => 1,
min => 0,
pointer => '',
tag => 'PLAC',
value => '<PLACE_LIVING_ORDINANCE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 421,
max => 'M',
min => 0,
pointer => '',
value => '<<SOURCE_CITATION>>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => '+1',
line => 422,
max => 'M',
min => 0,
pointer => '',
selection => 1,
value => '<<NOTE_STRUCTURE>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 416,
max => 1,
min => 1,
tag => 'BAPL'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 425,
max => 1,
min => 0,
pointer => '',
tag => 'STAT',
value => '<LDS_BAPTISM_DATE_STATUS>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 426,
max => 1,
min => 0,
pointer => '',
tag => 'DATE',
value => '<DATE_LDS_ORD>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 427,
max => 1,
min => 0,
pointer => '',
tag => 'TEMP',
value => '<TEMPLE_CODE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 428,
max => 1,
min => 0,
pointer => '',
tag => 'PLAC',
value => '<PLACE_LIVING_ORDINANCE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 429,
max => 'M',
min => 0,
pointer => '',
value => '<<SOURCE_CITATION>>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => '+1',
line => 430,
max => 'M',
min => 0,
pointer => '',
selection => 1,
value => '<<NOTE_STRUCTURE>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 424,
max => 1,
min => 1,
tag => 'CONL'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 433,
max => 1,
min => 0,
pointer => '',
tag => 'STAT',
value => '<LDS_ENDOWMENT_DATE_STATUS>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 434,
max => 1,
min => 0,
pointer => '',
tag => 'DATE',
value => '<DATE_LDS_ORD>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 435,
max => 1,
min => 0,
pointer => '',
tag => 'TEMP',
value => '<TEMPLE_CODE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 436,
max => 1,
min => 0,
pointer => '',
tag => 'PLAC',
value => '<PLACE_LIVING_ORDINANCE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 437,
max => 'M',
min => 0,
pointer => '',
value => '<<SOURCE_CITATION>>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => '+1',
line => 438,
max => 'M',
min => 0,
pointer => '',
selection => 1,
value => '<<NOTE_STRUCTURE>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 432,
max => 1,
min => 1,
tag => 'ENDL'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 441,
max => 1,
min => 0,
pointer => '',
tag => 'STAT',
value => '<LDS_CHILD_SEALING_DATE_STATUS>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 442,
max => 1,
min => 0,
pointer => '',
tag => 'DATE',
value => '<DATE_LDS_ORD>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 443,
max => 1,
min => 0,
pointer => '',
tag => 'TEMP',
value => '<TEMPLE_CODE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 444,
max => 1,
min => 0,
pointer => '',
tag => 'PLAC',
value => '<PLACE_LIVING_ORDINANCE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 445,
max => 1,
min => 1,
pointer => 1,
tag => 'FAMC',
value => '<XREF:FAM>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 446,
max => 'M',
min => 0,
pointer => '',
value => '<<SOURCE_CITATION>>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => '+1',
line => 447,
max => 'M',
min => 0,
pointer => '',
selection => 1,
value => '<<NOTE_STRUCTURE>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 440,
max => 1,
min => 1,
tag => 'SLGC'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 413,
selection => 1,
structure => 'LDS_INDIVIDUAL_ORDINANCE'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 454,
max => 1,
min => 0,
pointer => '',
tag => 'STAT',
value => '<LDS_SPOUSE_SEALING_DATE_STATUS>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 455,
max => 1,
min => 0,
pointer => '',
tag => 'DATE',
value => '<DATE_LDS_ORD>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 456,
max => 1,
min => 0,
pointer => '',
tag => 'TEMP',
value => '<TEMPLE_CODE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 457,
max => 1,
min => 0,
pointer => '',
tag => 'PLAC',
value => '<PLACE_LIVING_ORDINANCE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 458,
max => 'M',
min => 0,
pointer => '',
value => '<<SOURCE_CITATION>>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => '+1',
line => 459,
max => 'M',
min => 0,
pointer => '',
value => '<<NOTE_STRUCTURE>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 453,
max => 1,
min => 1,
tag => 'SLGS'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 451,
structure => 'LDS_SPOUSE_SEALING'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => 0,
line => 465,
max => 1,
min => 1,
pointer => 1,
selection => 1,
tag => 'OBJE',
value => '<XREF:OBJE>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 468,
max => 1,
min => 1,
pointer => '',
tag => 'FORM',
value => '<MULTIMEDIA_FORMAT>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 469,
max => 1,
min => 0,
pointer => '',
tag => 'TITL',
value => '<DESCRIPTIVE_TITLE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 470,
max => 1,
min => 1,
pointer => '',
tag => 'FILE',
value => '<MULTIMEDIA_FILE_REFERENCE>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => '+1',
line => 471,
max => 'M',
min => 0,
pointer => '',
selection => 1,
value => '<<NOTE_STRUCTURE>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 467,
max => 1,
min => 1,
tag => 'OBJE'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 462,
selection => 1,
structure => 'MULTIMEDIA_LINK'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+1',
line => 479,
max => 'M',
min => 0,
pointer => '',
selection => 1,
value => '<<SOURCE_CITATION>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 478,
max => 1,
min => 1,
pointer => 1,
tag => 'NOTE',
value => '<XREF:NOTE>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 482,
max => 'M',
min => 0,
pointer => '',
tag => 'CONC',
value => '<SUBMITTER_TEXT>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 483,
max => 'M',
min => 0,
pointer => '',
tag => 'CONT',
value => '<SUBMITTER_TEXT>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => '+1',
line => 484,
max => 'M',
min => 0,
pointer => '',
selection => 1,
value => '<<SOURCE_CITATION>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 481,
max => 1,
min => 1,
pointer => '',
tag => 'NOTE',
value => '<SUBMITTER_TEXT>'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 475,
selection => 1,
structure => 'NOTE_STRUCTURE'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 491,
max => 1,
min => 0,
pointer => '',
tag => 'NPFX',
value => '<NAME_PIECE_PREFIX>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 492,
max => 1,
min => 0,
pointer => '',
tag => 'GIVN',
value => '<NAME_PIECE_GIVEN>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 493,
max => 1,
min => 0,
pointer => '',
tag => 'NICK',
value => '<NAME_PIECE_NICKNAME>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 494,
max => 1,
min => 0,
pointer => '',
tag => 'SPFX',
value => '<NAME_PIECE_SURNAME_PREFIX>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 495,
max => 1,
min => 0,
pointer => '',
tag => 'SURN',
value => '<NAME_PIECE_SURNAME>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 496,
max => 1,
min => 0,
pointer => '',
tag => 'NSFX',
value => '<NAME_PIECE_SUFFIX>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 497,
max => 'M',
min => 0,
pointer => '',
value => '<<SOURCE_CITATION>>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => '+1',
line => 498,
max => 'M',
min => 0,
pointer => '',
value => '<<NOTE_STRUCTURE>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 490,
max => 1,
min => 1,
pointer => '',
tag => 'NAME',
value => '<NAME_PERSONAL>'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 488,
structure => 'PERSONAL_NAME_STRUCTURE'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 504,
max => 1,
min => 0,
pointer => '',
tag => 'FORM',
value => '<PLACE_HIERARCHY>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 505,
max => 'M',
min => 0,
pointer => '',
value => '<<SOURCE_CITATION>>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => '+1',
line => 506,
max => 'M',
min => 0,
pointer => '',
value => '<<NOTE_STRUCTURE>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 503,
max => 1,
min => 1,
pointer => '',
tag => 'PLAC',
value => '<PLACE_VALUE>'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 501,
structure => 'PLACE_STRUCTURE'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 513,
max => 1,
min => 0,
pointer => '',
tag => 'PAGE',
value => '<WHERE_WITHIN_SOURCE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 515,
max => 1,
min => 0,
pointer => '',
tag => 'ROLE',
value => '<ROLE_IN_EVENT>'
}, 'Gedcom::Grammar' )
],
level => '+1',
line => 514,
max => 1,
min => 0,
pointer => '',
tag => 'EVEN',
value => '<EVENT_TYPE_CITED_FROM>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 517,
max => 1,
min => 0,
pointer => '',
tag => 'DATE',
value => '<ENTRY_RECORDING_DATE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+3',
line => 519,
max => 'M',
min => 0,
pointer => '',
tag => 'CONC',
value => '<TEXT_FROM_SOURCE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+3',
line => 520,
max => 'M',
min => 0,
pointer => '',
tag => 'CONT',
value => '<TEXT_FROM_SOURCE>'
}, 'Gedcom::Grammar' )
],
level => '+2',
line => 518,
max => 'M',
min => 0,
pointer => '',
tag => 'TEXT',
value => '<TEXT_FROM_SOURCE>'
}, 'Gedcom::Grammar' )
],
level => '+1',
line => 516,
max => 1,
min => 0,
tag => 'DATA'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 521,
max => 1,
min => 0,
pointer => '',
tag => 'QUAY',
value => '<CERTAINTY_ASSESSMENT>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 522,
max => 'M',
min => 0,
pointer => '',
value => '<<MULTIMEDIA_LINK>>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => '+1',
line => 523,
max => 'M',
min => 0,
pointer => '',
selection => 1,
value => '<<NOTE_STRUCTURE>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 512,
max => 1,
min => 1,
pointer => 1,
tag => 'SOUR',
value => '<XREF:SOUR>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 526,
max => 'M',
min => 0,
pointer => '',
tag => 'CONC',
value => '<SOURCE_DESCRIPTION>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 527,
max => 'M',
min => 0,
pointer => '',
tag => 'CONT',
value => '<SOURCE_DESCRIPTION>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 529,
max => 'M',
min => 0,
pointer => '',
tag => 'CONC',
value => '<TEXT_FROM_SOURCE>'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+2',
line => 530,
max => 'M',
min => 0,
pointer => '',
tag => 'CONT',
value => '<TEXT_FROM_SOURCE>'
}, 'Gedcom::Grammar' )
],
level => '+1',
line => 528,
max => 'M',
min => 0,
pointer => '',
tag => 'TEXT',
value => '<TEXT_FROM_SOURCE>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [],
level => '+1',
line => 531,
max => 'M',
min => 0,
pointer => '',
selection => 1,
value => '<<NOTE_STRUCTURE>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 525,
max => 1,
min => 1,
pointer => '',
tag => 'SOUR',
value => '<SOURCE_DESCRIPTION>'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 509,
selection => 1,
structure => 'SOURCE_CITATION'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 538,
max => 'M',
min => 0,
pointer => '',
value => '<<NOTE_STRUCTURE>>'
}, 'Gedcom::Grammar' ),
bless( {
file => '*',
items => [
bless( {
file => '*',
items => [],
level => '+2',
line => 540,
max => 1,
min => 0,
pointer => '',
tag => 'MEDI',
value => '<SOURCE_MEDIA_TYPE>'
}, 'Gedcom::Grammar' )
],
level => '+1',
line => 539,
max => 'M',
min => 0,
pointer => '',
tag => 'CALN',
value => '<SOURCE_CALL_NUMBER>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 537,
max => 1,
min => 1,
pointer => 1,
tag => 'REPO',
value => '<XREF:REPO>'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 535,
structure => 'SOURCE_REPOSITORY_CITATION'
}, 'Gedcom::Grammar' ),
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [
bless( {
_items => 1,
file => '*',
gedcom => {},
items => [],
level => '+1',
line => 547,
max => 'M',
min => 0,
pointer => '',
value => '<<NOTE_STRUCTURE>>'
}, 'Gedcom::Grammar' )
],
level => 0,
line => 546,
max => 1,
min => 1,
pointer => 1,
tag => 'FAMS',
value => '<XREF:FAM>'
}, 'Gedcom::Grammar' )
],
level => -1,
line => 544,
structure => 'SPOUSE_TO_FAMILY_LINK'
}, 'Gedcom::Grammar' )
],
level => -2,
line => 0,
stored_item => undef,
version => '5.5'
}, 'Gedcom::Grammar' );
